# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ExperimentItemReference(UniversalBaseModel):
    """
    Experiment reference with ID, name, dataset ID, and dataset item ID
    """

    id: str = pydantic.Field()
    """
    Experiment ID
    """

    name: str = pydantic.Field()
    """
    Experiment name
    """

    dataset_id: str = pydantic.Field()
    """
    Dataset ID
    """

    dataset_item_id: str = pydantic.Field()
    """
    Dataset Item ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
